def PrintHello():
    """A simple function that says hello...
    
    Parameters
    ----------
    nothing : str
        Nothing at all
    nothing_at_all : bool, optional
        A flag not used to do anything (default is False)

    Returns
    -------
    str
        A str saying Hello
    
    """
    
    print("Hello from the Oxynet Python package")
    
    return